@@ -5,7 +5,7 @@ from functools import reduce
 
 from django.template import Node, Variable
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.auth.models import AnonymousUser
 from django.db.models import Q
 from django.core import exceptions
