@@ -1,7 +1,7 @@
 from tendenci.apps.registry.sites import site
 from tendenci.apps.registry.base import CoreRegistry
 from tendenci.apps.boxes.models import Box
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class BoxRegistry(CoreRegistry):
