@@ -3,7 +3,7 @@ from builtins import str
 from django.db import models
 from django.urls import reverse
 from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.contenttypes.fields import GenericRelation
 
 from tendenci.libs.tinymce import models as tinymce_models
