@@ -1,4 +1,4 @@
-from tendenci.core.perms.managers import TendenciBaseManager
+from tendenci.apps.perms.managers import TendenciBaseManager
 
 class DiscountManager(TendenciBaseManager):
     """
