@@ -1,5 +1,4 @@
-from django.utils.translation import ugettext_noop as _
-from django.db.models.signals import post_migrate
+from django.utils.translation import gettext_noop as _
 
 from tendenci.apps.notifications import models as notification
 
