@@ -1,6 +1,6 @@
 import uuid
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.perms.models import TendenciBaseModel
 
