@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 FIELD_MAX_LENGTH = 2000
 LABEL_MAX_LENGTH = 255
