@@ -1,6 +1,6 @@
 from django import forms
 from django.forms.models import BaseInlineFormSet
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 class BaseFieldFormSet(BaseInlineFormSet):
     def clean(self):
