@@ -1,13 +1,13 @@
 from django.db import models
 from django.urls import reverse
-from django.utils.translation import ugettext, ugettext_lazy as _
+from django.utils.translation import gettext, gettext_lazy as _
 from django.contrib.auth.models import User
 from django.contrib.contenttypes.fields import GenericRelation
 from django.utils.safestring import mark_safe
 from django.contrib.contenttypes.models import ContentType
 
 from django_countries import countries as COUNTRIES
-from localflavor.us.us_states import STATE_CHOICES
+from localflavor.us.us_states import STATE_CHOICES, US_STATES
 from localflavor.ca.ca_provinces import PROVINCE_CHOICES
 
 from tendenci.apps.forms_builder.forms.settings import FIELD_MAX_LENGTH, LABEL_MAX_LENGTH
@@ -119,7 +119,7 @@ class Form(TendenciBaseModel):
         help_text=_("One or more email addresses for form recipients, separated by commas"),
         max_length=2000)
     completion_url = models.CharField(_("Completion URL"), max_length=1000, blank=True, null=True,
-        help_text=_("Redirect to this page after form completion. Absolute URLS should begin with http. Relative URLs should begin with a forward slash (/)."))
+        help_text=_("Optionally, redirect to this page after form completion. Absolute URLS should begin with http. Relative URLs should begin with a forward slash (/)."))
     template = models.CharField(_('Template'), max_length=50, blank=True)
     group = models.ForeignKey(Group, null=True, default=None, on_delete=models.SET_NULL)
 
@@ -153,6 +153,7 @@ class Form(TendenciBaseModel):
         verbose_name_plural = _("Forms")
 #         permissions = (("view_form", _("Can view form")),)
         app_label = 'forms'
+        ordering = ('-id',)
 
     def __str__(self):
         return self.title
@@ -179,13 +180,13 @@ class Form(TendenciBaseModel):
     @mark_safe
     def admin_link_view(self):
         url = self.get_absolute_url()
-        return "<a href='%s'>%s</a>" % (url, ugettext("View on site"))
+        return "<a href='%s'>%s</a>" % (url, gettext("View on site"))
     admin_link_view.short_description = ""
 
     @mark_safe
     def admin_link_export(self):
         url = reverse("admin:forms_form_export", args=(self.id,))
-        return "<a href='%s'>%s</a>" % (url, ugettext("Export entries"))
+        return "<a href='%s'>%s</a>" % (url, gettext("Export entries"))
     admin_link_export.short_description = ""
 
     def has_files(self):
@@ -270,9 +271,12 @@ class Field(OrderingBaseModel):
                                ('','-----------'))
             choices = initial_choices + tuple(countries)
         elif self.field_type == 'StateProvinceField':
-            choices = (('','-----------'),) + tuple((state, state_f.title()) for state, state_f in STATE_CHOICES) \
-                                + tuple((prov, prov_f.title()) for prov, prov_f in PROVINCE_CHOICES)
-            choices = sorted(choices)
+            if get_setting('site', 'global', 'usstatesonly'):
+                choices = (('', '-----------'),) + tuple((state, state_f.title()) for state, state_f in US_STATES)
+            else:
+                choices = (('','-----------'),) + tuple((state, state_f.title()) for state, state_f in STATE_CHOICES) \
+                                    + tuple((prov, prov_f.title()) for prov, prov_f in PROVINCE_CHOICES)
+                choices = sorted(choices)
         elif self.field_function == 'Recipients':
             choices = [(label+':'+val, label) for label, val in (i.split(":") for i in self.choices.split(","))]
         else:
@@ -485,7 +489,7 @@ class FormEntry(models.Model):
         anonymous_creator = None
 
         if emailfield:
-            user_list = User.objects.filter(email=emailfield).order_by('-last_login')
+            user_list = User.objects.filter(email__iexact=emailfield).order_by('-last_login')
             if user_list:
                 anonymous_creator = user_list[0]
             else:
