@@ -9,7 +9,7 @@ import warnings
 from django import template
 from django.core.cache import cache
 from django.utils.safestring import mark_safe
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 from django.utils.html import escape
 from django.utils.translation import gettext as _
 from django.utils import dateformat
@@ -98,7 +98,7 @@ def pybb_link(object, anchor=''):
 
     url = hasattr(object, 'get_absolute_url') and object.get_absolute_url() or None
     #noinspection PyRedeclaration
-    anchor = anchor or smart_text(object)
+    anchor = anchor or smart_str(object)
     return mark_safe('<a href="%s">%s</a>' % (url, escape(anchor)))
 
 
