@@ -1,7 +1,7 @@
 from datetime import date, datetime
 from django import forms
 from django.db.models.fields import CharField, DecimalField
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.invoices.models import Invoice
 from tendenci.apps.events.models import Event
