@@ -4,7 +4,7 @@ from datetime import datetime
 from django.db import models
 from django.urls import reverse
 from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes.fields import GenericForeignKey
 from django.db.models.signals import post_save
@@ -277,6 +277,20 @@ class Invoice(models.Model):
             _object = None
         return _object
 
+    @property
+    def use_third_party_payment(self):
+        obj = self.get_object()
+        if hasattr(obj, 'use_third_party_payment'):
+            return getattr(obj, 'use_third_party_payment')
+        return False
+
+    @property
+    def external_payment_link(self):
+        obj = self.get_object()
+        if hasattr(obj, 'external_payment_link'):
+            return getattr(obj, 'external_payment_link')
+        return ''
+
     def get_donation_amount(self):
         obj = self.get_object()
         if obj and hasattr(obj, 'donation_amount'):
@@ -328,6 +342,12 @@ class Invoice(models.Model):
             if self.guid == guid:
                 return True
 
+        obj = self.get_object()
+        if obj and hasattr(obj, 'allow_adjust_invoice_by'):
+            # example: chapter leaders can view/adjust invoices for their chapter memberships.
+            if obj.allow_adjust_invoice_by(user2_compare):
+                return True
+
         if user2_compare.is_authenticated:
             if user2_compare in [self.creator, self.owner] or \
                     user2_compare.email == self.bill_to_email:
@@ -339,27 +359,35 @@ class Invoice(models.Model):
         return self.allow_view_by(user2_compare,  guid)
 
     # if this invoice allows edit by user2_compare
-    def allow_edit_by(self, user2_compare, guid=''):
-        boo = False
+    def allow_edit_by(self, user2_compare):
+        if not user2_compare.is_authenticated:
+            return False
+
         if user2_compare.is_superuser:
-            boo = True
+            return True
         else:
             if user2_compare and user2_compare.id > 0:
                 if has_perm(user2_compare, 'invoices.change_invoice'):
                     return True
 
-                if self.creator == user2_compare or \
-                        self.owner == user2_compare or \
-                        self.bill_to_email == user2_compare.email:
-                    if self.status == 1:
-                        # user can only edit a non-tendered invoice
-                        if not self.is_tendered:
-                            boo = True
-            else:
-                if self.guid and self.guid == guid:  # for anonymous user
-                    if self.status == 1 and not self.is_tendered:
-                        boo = True
-        return boo
+                obj = self.get_object()
+                if obj and hasattr(obj, 'allow_adjust_invoice_by'):
+                    # example: chapter leaders can view/adjust invoices for their chapter memberships.
+                    if obj.allow_adjust_invoice_by(user2_compare):
+                        return True
+
+#                 if self.creator == user2_compare or \
+#                         self.owner == user2_compare or \
+#                         self.bill_to_email == user2_compare.email:
+#                     if self.status:
+#                         # user can only edit a non-tendered invoice
+#                         if not self.is_tendered:
+#                             return True
+#             else:
+#                 if self.guid and self.guid == guid:  # for anonymous user
+#                     if self.status and not self.is_tendered:
+#                         return True
+        return False
 
     def make_payment(self, user, amount):
         """
