@@ -1,4 +1,4 @@
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.registry.sites import site
 from tendenci.apps.site_settings.utils import get_setting
