@@ -1,7 +1,7 @@
 from django.contrib.auth.models import AnonymousUser
 from django.db.models import Q
 from django.template import Library, TemplateSyntaxError, Variable
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.db.models import Count
 
 from tendenci.apps.jobs.models import Job
