@@ -277,8 +277,8 @@ class Migration(migrations.Migration):
                 ('admin_fee', models.DecimalField(decimal_places=2, default=0, max_digits=15, blank=True, help_text='Admin fee for the first time processing', null=True, verbose_name='Admin Fee')),
                 ('require_approval', models.BooleanField(default=True, verbose_name='Require Approval')),
                 ('require_payment_approval', models.BooleanField(default=True, help_text='If checked, auto-approved memberships will require a successful online payment to be auto-approved.', verbose_name='Auto-approval requires payment')),
-                ('allow_renewal', models.BooleanField(default=True, verbose_name='Allow Renewal')),
-                ('renewal', models.BooleanField(default=False, verbose_name='Renewal Only')),
+                ('allow_renewal', models.BooleanField(default=True, help_text='If not selected, then this membership type cannot be renewed.', verbose_name='Allow Renewal')),
+                ('renewal', models.BooleanField(default=False, help_text='Reserve this membership type for renewals only, not available to new members.', verbose_name='Renewal Only')),
                 ('renewal_require_approval', models.BooleanField(default=True, verbose_name='Renewal Requires Approval')),
                 ('admin_only', models.BooleanField(default=True, verbose_name='Admin Only')),
                 ('never_expires', models.BooleanField(default=False, help_text='If selected, skip the Renewal Options.', verbose_name='Never Expires')),
