@@ -1,11 +1,10 @@
 import datetime
 from django.contrib.auth.decorators import login_required
-from django.shortcuts import render_to_response
-from django.template import RequestContext
-from django.db.models import Avg, Max, Min, Count, Sum
+from django.db.models import Sum
 
-from tendenci.core.event_logs.models import EventLog
-from tendenci.core.base.http import Http403
+from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
+from tendenci.apps.event_logs.models import EventLog
+from tendenci.apps.base.http import Http403
 from tendenci.apps.metrics.models import Metric
 
 
@@ -27,5 +26,5 @@ def index(request, template_name="metrics/index.html"):
 
     EventLog.objects.log()
 
-    return render_to_response(template_name, locals(),
-        context_instance=RequestContext(request))
+    return render_to_resp(request=request, template_name=template_name,
+        context=locals())
