@@ -1,3 +1,4 @@
+
 from django.core.management.base import BaseCommand
 from django.core.exceptions import ObjectDoesNotExist
 
@@ -13,8 +14,8 @@ class Command(BaseCommand):
         users = User.objects.all()
         for user in users:
             try:
-                profile = user.get_profile()
+                profile = user.profile
             except ObjectDoesNotExist:
                 profile = Profile.objects.create_profile(user)
                 if options['verbosity'] > 1:
-                    print profile
+                    print(profile)
