@@ -1,18 +1,16 @@
-from optparse import make_option
+
 from django.core.management.base import BaseCommand
-from django.core.exceptions import ObjectDoesNotExist
 
 class Command(BaseCommand):
     """
     Get/Delete list of contributors, non-contributors and total users
     """
 
-    option_list = BaseCommand.option_list + (
-        make_option('-d', '--delete',
+    def add_arguments(self, parser):
+        parser.add_argument('-d', '--delete',
         action='store_true',
         default=False,
-        help='Delete non contributing users'),
-    )
+        help='Delete non contributing users')
 
     def handle(self, *args, **options):
         from django.contrib.auth.models import User
@@ -20,7 +18,7 @@ class Command(BaseCommand):
         contribs = []
 
         try:
-            from tendenci.addons.directories.models import Directory
+            from tendenci.apps.directories.models import Directory
             for directory in Directory.objects.all():
                 contribs.append(directory.creator)
                 contribs.append(directory.owner)
@@ -28,7 +26,7 @@ class Command(BaseCommand):
             pass
 
         try:
-            from tendenci.addons.articles.models import Article
+            from tendenci.apps.articles.models import Article
             for article in Article.objects.all():
                 contribs.append(article.creator)
                 contribs.append(article.owner)
@@ -36,7 +34,7 @@ class Command(BaseCommand):
             pass
 
         try:
-            from tendenci.addons.events.models import Event
+            from tendenci.apps.events.models import Event
             for event in Event.objects.all():
                 contribs.append(event.creator)
                 contribs.append(event.owner)
@@ -44,7 +42,7 @@ class Command(BaseCommand):
             pass
 
         try:
-            from tendenci.addons.photos.models import Photo
+            from tendenci.apps.photos.models import Photo
             for photo in Photo.objects.all():
                 contribs.append(photo.creator)
                 contribs.append(photo.owner)
@@ -60,7 +58,7 @@ class Command(BaseCommand):
             pass
 
         try:
-            from tendenci.addons.news.models import News
+            from tendenci.apps.news.models import News
             for news in News.objects.all():
                 contribs.append(news.creator)
                 contribs.append(news.owner)
@@ -68,12 +66,12 @@ class Command(BaseCommand):
             pass
 
         contribs = list(set(contribs))  # remove duplicates
-        slackers = User.objects.exclude(username__in=[c.username for c in contribs])
+        slackers = User.objects.exclude(username__in=[c.username for c in contribs if c])
 
-        print 'contribs', len(contribs)
-        print 'slackers', slackers.count()
-        print 'everyone', User.objects.count()
-        print 'Pass the -d or --delete fn to delete no contributors'
+        print('contribs', len(contribs))
+        print('slackers', slackers.count())
+        print('everyone', User.objects.count())
+        print('Pass the -d or --delete fn to delete no contributors')
 
         delete = options['delete']
 
@@ -86,9 +84,9 @@ class Command(BaseCommand):
             cursor.execute('SET FOREIGN_KEY_CHECKS=0;')
             for slacker in slackers:
                 try:
-                    print slacker
+                    print(slacker)
                     slacker.delete()
-                except IntegrityError as e:
-                    print 'Integrity Error deleting', slacker
+                except IntegrityError:
+                    print('Integrity Error deleting', slacker)
 
-            cursor.execute('SET FOREIGN_KEY_CHECKS=1;')
\ No newline at end of file
+            cursor.execute('SET FOREIGN_KEY_CHECKS=1;')
