@@ -9,7 +9,7 @@ from io import BytesIO
 from django.db import models
 from django.urls import reverse
 from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.core.files.storage import default_storage
 from django.core.files import File
 from django.conf import settings
