@@ -5,8 +5,8 @@ from tendenci.apps.search.indexes import CustomSearchIndex
 
 class RecurringPaymentIndex(CustomSearchIndex, indexes.Indexable):
     text = indexes.CharField(document=True, use_template=True)
-    user = indexes.CharField(model_attr='user', faceted=True)
-    user_object = indexes.CharField(model_attr='user', faceted=True)
+    user = indexes.CharField(model_attr='user', faceted=True, null=True)
+    user_object = indexes.CharField(model_attr='user', faceted=True, null=True)
     description = indexes.CharField(model_attr='description')
     payment_amount = indexes.FloatField(model_attr='payment_amount')
 
@@ -19,12 +19,10 @@ class RecurringPaymentIndex(CustomSearchIndex, indexes.Indexable):
         return 'update_dt'
 
     def prepare_user_object(self, obj):
-        return obj.user.username
+        return obj.user and obj.user.username
 
     def prepare_user(self, obj):
-        return "%s" % (
-            obj.user.get_full_name,
-        )
+        return obj.user and obj.user.get_full_name
 
     def prepare_order(self, obj):
         return obj.create_dt
