@@ -3,7 +3,7 @@ import uuid
 
 from django.db import models
 #from django.urls import reverse
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.contenttypes.fields import GenericRelation
 
 from tendenci.apps.perms.models import TendenciBaseModel
