@@ -1,7 +1,7 @@
 from django.conf import settings
 from django.core.paginator import Paginator, InvalidPage
 from django.http import Http404
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from tendenci.apps.theme.shortcuts import themed_response as render_to_resp
 from tendenci.apps.search.forms import ModelSearchForm
