@@ -1,7 +1,7 @@
 from datetime import datetime
 
 from django.db.models import Q
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.urls import reverse
 
 from tendenci.apps.rss.feedsmanager import SubFeed
