@@ -1,8 +1,7 @@
 import os
 import zipfile
-import urllib
+from urllib.request import urlopen
 from shutil import rmtree, move
-from optparse import make_option
 
 from django.core.management.base import BaseCommand, CommandError
 from django.conf import settings
@@ -13,30 +12,29 @@ class Command(BaseCommand):
     Example: python manage.py install_theme prfirm [theme_url]
     """
 
-    option_list = BaseCommand.option_list + (
-        make_option(
+    def add_arguments(self, parser):
+        parser.add_argument(
             '--all', action='store_true',
             dest='all', default=False,
-            help='Install all themes'),
-    )
+            help='Install all themes')
 
     def handle(self, theme_name=None, theme_url=None, **options):
         """
         Downloads a theme to be installed on the site and sets
         it as the active theme.
         """
-        from tendenci.core.base.models import UpdateTracker
+        from tendenci.apps.base.models import UpdateTracker
 
         UpdateTracker.start()
         all_themes = options.get('all', False)
 
         if not theme_url:
-            theme_url = "https://github.com/tendenci/tendenci-themes/archive/master.zip"
+            theme_url = "https://github.com/tendenci/tendenci-project-template/archive/master.zip"
 
         if not (theme_name or all_themes):
             raise CommandError('Specify a theme name, or add --all for all themes')
 
-        themes_dir_path = os.path.join(settings.PROJECT_ROOT, "themes")
+        themes_dir_path = settings.ORIGINAL_THEMES_DIR
         if theme_name:
             theme_path = os.path.join(themes_dir_path, theme_name)
 
@@ -45,7 +43,7 @@ class Command(BaseCommand):
                 raise CommandError('The theme %s is already installed.' % theme_name)
 
         # Copy the theme files down
-        theme_download = urllib.urlopen(theme_url)
+        theme_download = urlopen(theme_url)
         theme_zip_path = os.path.join(themes_dir_path, "themes.zip")
         theme_zip = open(theme_zip_path, 'wb')
         theme_zip.write(theme_download.read())
@@ -72,7 +70,7 @@ class Command(BaseCommand):
         os.remove(theme_zip_path)
 
         # Move the themes out of the unzipped folder
-        unzip_dir_path = os.path.join(themes_dir_path, unzip_dirname)
+        unzip_dir_path = os.path.join(themes_dir_path, os.path.join(unzip_dirname, 'themes'))
         if all_themes:
             for name in os.listdir(unzip_dir_path):
                 # Check for themes
