@@ -1,10 +1,6 @@
-import re
-import os
+
 from django.core.management import call_command
-from django.core.management.base import BaseCommand, CommandError
-from django.db import connections, transaction, DEFAULT_DB_ALIAS
-from StringIO import StringIO
-from django.conf import settings
+from django.core.management.base import BaseCommand
 
 
 class Command(BaseCommand):
@@ -12,11 +8,15 @@ class Command(BaseCommand):
     Example: python manage.py set_theme thinksmart
     """
 
+    def add_arguments(self, parser):
+        # Positional arguments
+        parser.add_argument('theme_name')
+
     def handle(self, theme_name, **options):
         """
         Set the website theme via theme name
         """
-        from tendenci.core.site_settings.models import Setting
+        from tendenci.apps.site_settings.models import Setting
 
         try:
             setting = Setting.objects.get(
@@ -31,6 +31,4 @@ class Command(BaseCommand):
             call_command('clear_cache')
         except Setting.DoesNotExist:
             if int(options['verbosity']) > 0:
-                print "We could not update the theme because the setting or theme is not available."
-
-
+                print("We could not update the theme because the setting or theme is not available.")
