@@ -1,7 +1,7 @@
 from django.db import models
 from django.conf import settings
 from django.contrib.auth.models import User
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.contrib.contenttypes.fields import GenericRelation
 from django.utils.safestring import mark_safe
 
@@ -14,11 +14,11 @@ from tendenci.apps.perms.object_perms import ObjectPermission
 # Abstract base class for authority fields
 class TendenciBaseModel(models.Model):
     # authority fields
-    allow_anonymous_view = models.NullBooleanField(_("Public can view"), default=False)
-    allow_user_view = models.NullBooleanField(_("Signed in user can view"))
-    allow_member_view = models.NullBooleanField()
-    allow_user_edit = models.NullBooleanField(_("Signed in user can change"))
-    allow_member_edit = models.NullBooleanField()
+    allow_anonymous_view = models.BooleanField(_("Public can view"), default=False)
+    allow_user_view = models.BooleanField(_("Signed in user can view"), default=False)
+    allow_member_view = models.BooleanField(default=False)
+    allow_user_edit = models.BooleanField(_("Signed in user can change"), default=False)
+    allow_member_edit = models.BooleanField(default=False)
 
     create_dt = models.DateTimeField(auto_now_add=True)
     update_dt = models.DateTimeField(auto_now=True)
@@ -26,7 +26,7 @@ class TendenciBaseModel(models.Model):
     creator_username = models.CharField(max_length=150)
     owner = models.ForeignKey(User, related_name="%(app_label)s_%(class)s_owner" , on_delete=models.CASCADE)
     owner_username = models.CharField(max_length=150)
-    status = models.NullBooleanField("Active", default=True)
+    status = models.BooleanField("Active", default=True)
     status_detail = models.CharField(max_length=50, default='active')
 
     class Meta:
