@@ -7,7 +7,7 @@ from itertools import chain
 from django.http import HttpResponse
 from django.utils.translation import gettext_lazy as _
 from django.db.models.fields import DateTimeField, DateField
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.db.models import Q
 from django import forms
 #from django.forms.models import fields_for_model
@@ -383,9 +383,9 @@ class ReportAdmin(object):
         value = self.get_grouper_text(value, groupby_field, model_field)
         if value is None or str(value) == u'None':
             if groupby_field is None or str(groupby_field) == u'None':
-                value = force_text(_('Results'))
+                value = force_str(_('Results'))
             else:
-                value = force_text(_('Nothing'))
+                value = force_str(_('Nothing'))
         return value
 
     def _get_value_text(self, index, value):
@@ -510,7 +510,7 @@ class ReportAdmin(object):
             if not self.model:
                 title = _('Unnamed report')
             else:
-                title = force_text(self.model._meta.verbose_name_plural).lower().capitalize()
+                title = force_str(self.model._meta.verbose_name_plural).lower().capitalize()
         return title
 
     def get_render_context(self, request, extra_context={}, by_row=None):
@@ -726,7 +726,7 @@ class ReportAdmin(object):
                                     field.choices.insert(0, ('', '---------'))
                                     field.initial = ''
 
-                        field.label = force_text(_(field.label))
+                        field.label = force_str(_(field.label))
 
                 else:
                     if isinstance(v, (forms.BooleanField)):
@@ -885,7 +885,7 @@ class ReportAdmin(object):
         header_row = self.get_empty_row_asdict(self.get_fields(), ReportValue(''))
         for report_total_field, fun in row_config.items():
             if hasattr(fun, 'caption'):
-                value = force_text(fun.caption)
+                value = force_str(fun.caption)
             else:
                 value = '&nbsp;'
             header_row[report_total_field] = value
