@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from django import template
 from django.template.loader import render_to_string
-from django.utils.translation import ugettext_lazy as _
 
 
 register = template.Library()
@@ -19,7 +18,7 @@ class ModelReportInlineNode(template.Node):
         if row.is_value():
             inline_context = inline.get_render_context(request, by_row=row)
             if len(inline_context['report_rows']) > 0:
-                return render_to_string('model_report/includes/report_inline.html', inline_context)
+                return render_to_string(template_name='model_report/includes/report_inline.html', context=inline_context)
         return ''
 
 
@@ -28,5 +27,5 @@ def model_report_render_inline(parser, token):
     try:
         tag_name, inline, row = token.split_contents()
     except ValueError:
-        raise template.TemplateSyntaxError(_("%(b)r tag requires arguments" % {'b': token.contents.split()[0]}))
+        raise template.TemplateSyntaxError("%r tag requires arguments" % token.contents.split()[0])
     return ModelReportInlineNode(inline, row)
