@@ -3,7 +3,7 @@ from decimal import Decimal
 from string import capwords
 from datetime import datetime
 from django.utils.translation import gettext_lazy as _
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.contrib.contenttypes.models import ContentType
 from tendenci.apps.entities.models import Entity
 
@@ -148,7 +148,7 @@ class ReportValue(object):
         """
         Render as text the value. This function also format the value.
         """
-        return force_text(self.format(self.value, instance=self))
+        return force_str(self.format(self.value, instance=self))
 
     def __repr__(self):
         return self.text()
