@@ -2,7 +2,7 @@
 from django import forms
 from django.template.loader import render_to_string
 from django.utils.translation import gettext as _
-from django.utils.encoding import force_text
+from django.utils.encoding import force_str
 from django.forms.widgets import DateInput
 
 
@@ -48,7 +48,7 @@ class RangeField(forms.MultiValueField):
                 widget=RangeWidget(widget),
                 *args, **kwargs
                 )
-        self.label = force_text(field_class().label)
+        self.label = force_str(field_class().label)
 
 
     def compress(self, data_list):
