@@ -1,4 +1,3 @@
-from django.template import Context
 from django.template.loader import get_template
 from django import template
 
@@ -36,26 +35,50 @@ def is_textinput(field):
 def is_fileinput(field):
     return "fileinput" in field.field.widget.__class__.__name__.lower()
 
+@register.filter
+def col_sm_width(field):
+    """
+    Get the width for the field column specified in the class "col-sm-x".
+    The width is calculated based on the size of the field.
+    """
+    f = field.field
+    if field.name == 'salutation':
+        return 5
+    if hasattr(f, 'widget') and 'size' in f.widget.attrs:
+        try:
+            size = int(f.widget.attrs['size'])
+            if size >= 30:
+                return 8
+            if size >= 25:
+                return 7
+            if size >= 20:
+                return 6
+            if size >= 10:
+                return 5
+            if size >= 6:
+                return 4
+            if size <= 5:
+                return 3
+        except:
+            pass
+    return 8
+
 @register.filter
 def styled_form(form):
     template = get_template('styled_forms/form.html')
-    c = Context({'form':form})
-    return template.render(c)
+    return template.render(context={'form':form})
 
 @register.filter
 def styled_multi_forms(forms):
     template = get_template('styled_forms/multi_form.html')
-    c = Context({'forms':forms})
-    return template.render(c)
+    return template.render(context={'forms':forms})
 
 @register.filter
 def styled_form_set(form_set):
     template = get_template('styled_forms/form_set.html')
-    c = Context({'form_set':form_set})
-    return template.render(c)
+    return template.render(context={'form_set':form_set})
 
 @register.filter
 def styled_dynamic_form_set(form_set):
     template = get_template('styled_forms/dynamic_form_set.html')
-    c = Context({'form_set':form_set})
-    return template.render(c)
+    return template.render(context={'form_set':form_set})
